.. DMCpy documentation master file, created by
   sphinx-quickstart on Wed Feb 28 17:31:13 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to DMCpy's documentation!
===================================
Welcome to the documentation page of the DMCpy software package developed for data treatment, conversion, and visualization for the powder and single crystal 
instrument DMC located at the Paul Scherrer Institute, Villigen Switzerland.

Table of contents
-----------------
Below is an overview of the provided documentation containing everything from physical/mathematical explanations of different concepts through code specific references to 
tutorials and guides on how to make use of DMCpy.

.. toctree::
   :maxdepth: 1

   introduction
   Tutorials/Tutorials
   


.. table:: Current information
   :widths: grid
   :align: left

   +---------------------------+
   | |version| (Github Master) |
   +---------------------------+
   |   |pypiversion|           |
   +---------------------------+
   |   |pypiPython|            |
   +---------------------------+
   |    |doi|                  |
   +---------------------------+

..   |  |travis|  |
..   +------------+
..   | |coverall| |
..   +------------+


.. .. |travis| image:: https://travis-ci.org/DMCpyPackage/DMCpy.svg?branch=master
..    :target: https://travis-ci.org/DMCpyPackage/DMCpy

.. .. |coverall| image:: https://coveralls.io/repos/github/DMCpyPackage/DMCpy/badge.svg?branch=master
..    :target: https://coveralls.io/github/DMCpyPackage/DMCpy?branch=master

.. |pypiPython| image:: https://img.shields.io/pypi/pyversions/DMCpy
    :alt: PyPI - Python Version
    :target: https://pypi.org/project/DMCpy/   


.. |doi| image:: https://zenodo.org/badge/360167173.svg
    :target: https://zenodo.org/badge/latestdoi/360167173


.. |version| image:: https://img.shields.io/github/v/release/Jakob-Lass/DMCpy   
    :alt: GitHub release (latest by date)
    :target: https://github.com/Jakob-Lass/DMCpy

.. |pypiversion| image:: https://img.shields.io/pypi/v/DMCpy   
    :alt: Pypi release (latest by date)
    :target: https://pypi.org/project/DMCpy/ 